This function measures the azimuth between two events. It returns a vector of
azimuths of the same length as the number of events in x, with the azimuth
for the last event of each track padded with an NA.
This function measures the azimuth between two events. It returns a vector of
azimuths of the same length as the number of events in x, with the azimuth
for the last event of each track padded with an NA.