This is a helper function to access the track id of each event in a move2 object; it returns content of the column designated "track_id_column" in the move2 object.
This is a helper function to access the track id of each event in a move2 object; it returns content of the column designated "track_id_column" in the move2 object.