Controls whether objects of class move2 use custom tidytracks printing or
the standard printing method supplied by move2.
Arguments
- value
Either
TRUE,FALSE, orNULL.TRUEregisters custom tidytracks printing,FALSEregisters standard move2 printing, andNULLreports which method is currently registered without changing anything.- sticky
Whether the supplied setting should persist across R sessions. If
FALSE, the method is changed only for the current R session. IfTRUE, the supplied value is also saved in the user-specific tidytracks configuration directory. Defaults toTRUE.
Value
If value is NULL, a logical scalar indicating whether tidytracks'
custom print method is currently registered. Otherwise, the supplied value
is returned invisibly after registration.